@@ -15,14 +15,19 @@ class LoggingLauncher(base.Launcher):
 
     def __call__(self, config: Any, command: str = ""):
         """Log parsed config params using logging module."""
-        # Setup logger
-        level = config.get("logging", {}).get("level")
+        # Extract parameters
+        params = config.get("logging") or {}
+        level = params.get("level")
+        log_config = params.get("log_config", True)
+
+        # Change verbosity level (applies to all loggers)
         if level is not None:
             logging.basicConfig(level=level)
 
-        # Parse config and log
-        for key, value in flatten(config):
-            LOGGER.info(f"- {key}: {value}")
+        # Log flattened config
+        if log_config:
+            for key, value in flatten(config):
+                LOGGER.info(f"- {key}: {value}")
 
         # Execute sub-launcher with no parser (already parsed)
         self.launcher(config=config, command=command)  # type: ignore
